# Security Policy

We take security and privacy matters very seriously. We appreciate that our users place a high degree of confidence and trust in this project and we strive to meet those expectations.

## Vulnerability Reporting

If you believe you've discovered a potential vulnerability in this project's security, please contact us at echarris@smcm.edu. 

When reporting a potential vulnerability, please include as much of the following information as possible:

* A description of the vulnerability
* The impacted software or service and its version
* Proof-of-concept code and/or detailed steps to reproduce

## Secure Communications

If you're a security researcher and you believe that you have found a security issue within this project, email the details of your findings to echarris@smcm.edu. Use PGP to protect the message by using the public PGP key below.

## PGP Public Key

```
-----BEGIN PGP PUBLIC KEY BLOCK-----

NIoA/jd0S2zIH/Mqpwe45WRc7FMsalT4QoKir0EW0yjigVID
=hq5w
-----END PGP PUBLIC KEY BLOCK-----
```
